@@ -74,7 +74,8 @@ public class CreateServiceSchemaLockTable extends AbstractCreateTableImpl {
         return new String[]{"CREATE TABLE `serviceSchemaMigrationLock` (" + 
             "  `module` varchar(128) NOT NULL DEFAULT ''," + 
             "  `expires` bigint(20) DEFAULT NULL," + 
-            "  PRIMARY KEY (`module`))"};
+            "  PRIMARY KEY (`module`)" + 
+            ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci"};
     }
 
 }
