@@ -74,7 +74,8 @@ public class CreateServiceSchemaVersionTable extends AbstractCreateTableImpl {
         return new String[]{"CREATE TABLE `serviceSchemaVersion` (" + 
             "  `version` varchar(128) NOT NULL DEFAULT ''," + 
             "  `module` varchar(128) NOT NULL DEFAULT ''," + 
-            "  PRIMARY KEY (`version`,`module`))"};
+            "  PRIMARY KEY (`version`,`module`)" +
+            ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci"};
     }
 
 }
