@@ -65,6 +65,8 @@ import com.openexchange.groupware.ldap.User;
 import com.openexchange.mailmapping.MailResolver;
 import com.openexchange.mailmapping.MultipleMailResolver;
 import com.openexchange.mailmapping.ResolvedMail;
+import com.openexchange.rest.services.annotation.Role;
+import com.openexchange.rest.services.annotation.RoleAllowed;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -77,7 +79,8 @@ import com.openexchange.user.UserService;
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  * @since 7.8.0
  */
-@Path("/utilities/mailResolver/v1")
+@Path("/preliminary/utilities/mailResolver/v1")
+@RoleAllowed(Role.BASIC_AUTHENTICATED)
 public class MailMappingRESTService {
 
     private final ServiceLookup services;
